==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/ENERGYTARGETACTIVITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ENERGYTARGETACTIVITYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ENERGYTARGETACTIVITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYTARGETACTIVITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENERGYTARGETACTIVITYID_Type", propOrder = {
    "energytargetactivitycode",
    "description"
})
public class ENERGYTARGETACTIVITYID_Type {

    @XmlElement(name = "ENERGYTARGETACTIVITYCODE", required = true)
    protected String energytargetactivitycode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété energytargetactivitycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENERGYTARGETACTIVITYCODE() {
        return energytargetactivitycode;
    }

    /**
     * Définit la valeur de la propriété energytargetactivitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENERGYTARGETACTIVITYCODE(String value) {
        this.energytargetactivitycode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/ENERGYTARGETACTIVITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ENERGYTARGETACTIVITYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ENERGYTARGETACTIVITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYTARGETACTIVITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENERGYTARGETACTIVITYID_Type", propOrder = {
    "energytargetactivitycode",
    "description"
})
public class ENERGYTARGETACTIVITYID_Type {

    @XmlElement(name = "ENERGYTARGETACTIVITYCODE", required = true)
    protected String energytargetactivitycode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the energytargetactivitycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENERGYTARGETACTIVITYCODE() {
        return energytargetactivitycode;
    }

    /**
     * Sets the value of the energytargetactivitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENERGYTARGETACTIVITYCODE(String value) {
        this.energytargetactivitycode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
